/*
  SsODNet autocomplete function, based on jquery UI autocomplete native function.

  SsODNet REST API is currently in development. This release candidate is available 
  as a demonstrator, and must not be used as an operational service.

  Search is done via the autocomplete end-point of the SsODNet Resolver REST API:
    http://voparis-registry.obspm.fr/ssodnet/1/autocomplete/?q=

  Documentation:
    http://vo.imcce.fr/webservices/ssodnet/?api
    http://api.vo.obspm.fr/ssodnet/

  @author J. Berthier, J. Normand, IMCCE / Obs. de Paris / CNRS
  @copyright (c) 2013-2014, IMCCE
  @date 2014-04-29 
 */

$(function() {

  /* SsODNet REST API autocomplete end-point */
  var $autocompServer = "http://voparis-registry.obspm.fr/ssodnet/1/autocomplete";

  function split(val) {
    return val.split(/,\s*/);
  }

  function extractLast(term) {
    return split(term).pop();
  }

  /* Hack of _renderItem function to customize the output labels */
  $.ui.autocomplete.prototype._renderItem = function (ul, item) {
    item.label = item.label.replace(new RegExp("^(?![^&;]+;)(?!<[^<>]*)(" + $.ui.autocomplete.escapeRegex(extractLast(this.term)) + ")(?![^<>]*>)(?![^&;]+;)", "i"), "<span style='font-weight:bold;color:blue;'>$1</span>");
    return $("<li></li>")
            .data("item.autocomplete", item)
            .append("<a>" + item.label + " (" + item.type + ")" + "</a>" )
            .appendTo(ul);
  };

  /* Autocomplete function - single selection */
  $.fn.ssodnetautocomplete = function() {

    $(this).autocomplete({
       source: function(request, response) {
          $.ajax({
             url: $autocompServer,
             type: "GET",
             data: 'q="' + request.term + '"',
             dataType: "json",
             success: function(data, status, xhr) {
                response($.map(data.hits, function(item) {
                   return {
                      name: item['name'],
                      type: item['type'],
                      aliases: item['aliases'],
                      label: item['name'],
                      value: item['name']
                   };
                }));
             },
          });
       },
       minLength: 2
    });

  };

  /* Autocomplete function - multi selections */
  $.fn.ssodnetmultiautocomplete = function() {

    $(this).autocomplete({
       source: function(request, response) {
          $.ajax({
             url: $autocompServer,
             type: "GET",
             data: 'q="' + extractLast(request.term) + '"',
             dataType: "json",
             success: function(data, status, xhr) {
                response($.map(data.hits, function(item) {
                   var terms = split(request.term);
                   terms.pop(); // remove the current input
                   terms.push(item['name']); // add the selected item
                   terms.push(""); // add placeholder to get the comma-and-space at the end
                   var response = terms.join(", ");
                   return {
                      name: item['name'],
                      type: item['type'],
                      aliases: item['aliases'],
                      label: item['name'],
                      value: response
                   };
                }));
             },
          });
       },
       minLength: 2
    });

  };

});
